# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaMenu(Component):
    """An AnyaMenu component.
An Ant Design Menu Component
https://ant.design/components/menu
Adapted form https://github.com/CNFeffery/feffery-antd-components/blob/main/src/lib/components/AntdMenu.react.js

Keyword arguments:

- id (string; optional):
    The ID used to identify this component.

- className (string | dict; optional):
    CSS classes to be added to the component.

- currentKey (string; optional):
    Key of currently the selected menu item.

- defaultOpenKeys (list of strings; optional):
    Array with the keys of default opened sub-menus.

- defaultSelectedKey (string; optional):
    Key of default selected menu item.

- inlineCollapsed (boolean; default False):
    Whether the inline menu is collapsed.

- isTopNav (boolean; default False):
    Whether it is a top menu.

- key (string; optional):
    Unique ID of the menu item.

- menuItems (list; optional):
    Menu items.

- mode (a value equal to: 'vertical', 'horizontal', 'inline'; default 'vertical'):
    Type of menu: vertical | horizontal | inline.

- openKeys (list of strings; optional):
    Array with the keys of currently opened sub-menus.

- persisted_props (list of a value equal to: 'currentKey', 'openKeys's; default ['currentKey', 'openKeys']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    Popup menu.

- renderCollapsedButton (boolean; default False):
    Render collapsed button.

- style (dict; optional):
    Inline CSS style.

- theme (a value equal to: 'light', 'dark'; default 'light'):
    Color theme of the menu: light | dark."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaMenu'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, menuItems=Component.UNDEFINED, mode=Component.UNDEFINED, theme=Component.UNDEFINED, currentKey=Component.UNDEFINED, openKeys=Component.UNDEFINED, defaultOpenKeys=Component.UNDEFINED, defaultSelectedKey=Component.UNDEFINED, renderCollapsedButton=Component.UNDEFINED, popupContainer=Component.UNDEFINED, inlineCollapsed=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, isTopNav=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'currentKey', 'defaultOpenKeys', 'defaultSelectedKey', 'inlineCollapsed', 'isTopNav', 'key', 'menuItems', 'mode', 'openKeys', 'persisted_props', 'persistence', 'persistence_type', 'popupContainer', 'renderCollapsedButton', 'style', 'theme']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'currentKey', 'defaultOpenKeys', 'defaultSelectedKey', 'inlineCollapsed', 'isTopNav', 'key', 'menuItems', 'mode', 'openKeys', 'persisted_props', 'persistence', 'persistence_type', 'popupContainer', 'renderCollapsedButton', 'style', 'theme']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaMenu, self).__init__(**args)



from anya_dash import *
from dash import Dash, Output, Input, State, html


app = Dash(__name__)
app.layout = AnyaTheme(
    AnyaRow(
        AnyaCol(
            [
                AnyaTitle('Switch', level=3),
                AnyaSpace(
                    [
                        AnyaSwitch(
                            checkedChildren='Open',
                            unCheckedChildren='Close',
                            id='switch'
                        ),
                        AnyaButton('Swith: Close', type='dashed',
                                   id='switch-btn-ouput'),
                        AnyaSwitch(disabled=True, checked=True),
                    ],
                    direction='horizontal',
                    size='small',
                    align='center'
                ),
                html.Hr(),
                AnyaTitle('Date Picker', level=3),
                AnyaSpace(
                    [
                        AnyaDateRangePicker(
                            id='date-picker',
                            placement='bottomRight',
                            style={
                                'width': 275
                            }
                        ),
                        AnyaButton('Selected date: ...', type='dashed', id='date-picker-ouput'),
                    ],
                    direction='horizontal',
                    align='center'
                ),
                html.Hr(),
                AnyaTitle('Dropdowns', level=3),
                AnyaSpace(
                    [
                        AnyaSelect(
                            options=[
                                {
                                    'label': f'Choice {i}',
                                    'value': f'{i}'
                                }
                                for i in range(1, 6)
                            ],
                            defaultValue='1',
                            style={
                                'width': 200
                            },
                            id='select-1'
                        ),
                        AnyaSelect(
                            options=[
                                {
                                    'label': f'Choice {i}',
                                    'value': f'{i}'
                                }
                                for i in range(1, 6)
                            ],
                            mode='multiple',
                            value=['1', '3'],
                            style={
                                'width': 300
                            },
                            id='select-2'
                        ),
                        AnyaSelect(
                            id='dropdown',
                            options=[
                                {
                                    'group': 'Group 1',
                                    'options': [
                                        {
                                            'label': f'Choice 1-{i}',
                                            'value': f'1-{i}'
                                        }
                                        for i in range(1, 4)
                                    ]
                                },
                                {
                                    'group': 'Group 2',
                                    'options': [
                                        {
                                            'label': f'Choice 2-{i}',
                                            'value': f'2-{i}'
                                        }
                                        for i in range(1, 4)
                                    ]
                                }
                            ],
                            placeholder='Grouped Options',
                            style={
                                'width': 200
                            }
                        ),
                        AnyaButton('Selected value: ...',
                                   type='dashed', id='dropdown-btn-ouput'),
                    ],
                    direction='vertical',
                    size='small'
                ),
                html.Hr(),
                AnyaTitle('Radio Groups', level=3),
                AnyaRadioGroup(
                    options=[
                        {
                            'label': f'Choice {c}',
                            'value': c
                        }
                        for c in list('ABCDEF')
                    ],
                    defaultValue='A',
                    id='radio',
                    direction='vertical'
                ),
                AnyaButton('Selected value: ...',
                           type='dashed', id='radio-btn-ouput'),
                html.Hr(),
                AnyaTitle('Checkboxes', level=3),
                AnyaSpace(
                    [
                        AnyaCheckboxGroup(
                            options=[
                                {
                                    'label': f'Choice {i}',
                                    'value': f'{i}'
                                }
                                for i in range(5)
                            ],
                            value=[f'{i}' for i in range(5)],
                            id='checkbox',
                            includeSelectAll=True
                        ),
                        AnyaButton('Selected value: All',
                                   type='dashed', id='checkbox-btn-ouput'),
                    ],
                    align='center'
                ),
                AnyaTitle('Input Boxes', level=3),
                AnyaSpace(
                    [
                        AnyaInput(placeholder='mode="default"',
                                  style={'width': '500px'}),
                        AnyaInput(
                            placeholder='mode="search"',
                            style={'width': '500px'},
                            mode='search'
                        ),
                        AnyaInput(
                            placeholder='mode="text-area"',
                            style={'width': '500px'},
                            mode='text-area'
                        ),
                        AnyaInput(
                            placeholder='mode="password"',
                            style={'width': '500px'},
                            mode='password'
                        ),
                        AnyaInputNumber(
                            step=0.001,
                            defaultValue=0,
                            placeholder='step=0.001',
                            style={'width': '120px'},
                        )
                    ],
                    size='small',
                    direction='vertical'
                ),
                html.Hr(),
                AnyaTitle('Sliders', level=3),
                AnyaSpace(
                    [
                        AnyaSlider(
                            id='slider-point',
                            range=False,
                            min=0,
                            max=100,
                            tooltipVisible=True,
                            defaultValue=50,
                            style={
                                'width': 300
                            }
                        ),
                        AnyaSlider(
                            id='slider-range',
                            range=True,
                            tooltipVisible=True,
                            min=0,
                            max=100,
                            marks={0: '0', 100: '100'},
                            defaultValue=[20, 70],
                            style={
                                'width': 300
                            }
                        )

                    ],
                    direction='vertical',
                    size='small'
                )
            ],
            lg={'span': 18, 'offset': 3},
            md={'span': 20, 'offset': 2},
            xs=24,
            style={
                'backgroundColor': '#fff',
                'padding': '32px'
            }
        ),
        style={'backgroundColor': '#f3f6ff'}
    )
)


@app.callback(
    Output('switch-btn-ouput', 'children'),
    Input('switch', 'checked')
)
def dis_collapse(colapsed):
    return 'Swith: {}'.format(str(colapsed).title())


@app.callback(
    Output('dropdown-btn-ouput', 'children'),
    Input('dropdown', 'value')
)
def dis_collapse(value):
    return 'Selected value: {}'.format(value)


@app.callback(
    Output('radio-btn-ouput', 'children'),
    Input('radio', 'value')
)
def dis_collapse(value):
    return 'Selected value: {}'.format(value)


@app.callback(
    Output('checkbox-btn-ouput', 'children'),
    Input('checkbox', 'value')
)
def dis_collapse(value):
    return 'Selected value: {}'.format('; '.join(value))

@app.callback(
    Output('date-picker-ouput', 'children'),
    Input('date-picker', 'value')
)
def dis_collapse(value):
    if not value:
        value = []
    return 'Selected dates: {}'.format(' to '.join(value))


if __name__ == '__main__':
    app.run_server(debug=True)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaTabs(Component):
    """An AnyaTabs component.
An Ant Design Tag component
See https://ant.design/components/tabs

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content to display if itemContent is set to False.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- activeKey (string; optional):
    Current TabPane's key.

- centered (boolean; default False):
    Centers tabs.

- childCardBorder (boolean; default True):
    Whether the child card bordy should have borders.

- childCardStyle (dict; default {borderTop: 0}):
    Inline CSS style of the child card body.

- className (string; optional):
    CSS classes to be added to the component.

- defaultActiveKey (string; optional):
    Initial active TabPane's key, if activeKey is not set.

- disabledTabKeys (list of strings; optional):
    Array of keys of tabs to be disabled.

- itemContent (boolean; default False):
    Whether to display children content under each item, defaults to
    False.

- items (list of dicts; optional):
    Tab items.

    `items` is a list of dicts with keys:

    - children (a list of or a singular dash component, string or number; optional)

    - closable (boolean; optional)

    - disabled (boolean; optional)

    - forceRender (boolean; optional)

    - key (string; optional)

    - label (a list of or a singular dash component, string or number; optional)

- size (a value equal to: 'small', 'default', 'large'; default 'small'):
    Preset tab bar size.

- style (dict; optional):
    Inline CSS style.

- tabBarGutter (number; optional):
    The gap between tabs.

- tabPosition (a value equal to: 'top', 'left', 'right', 'bottom'; default 'top'):
    Position of tabs.

- type (a value equal to: 'line', 'card', ' editable-card'; default 'card'):
    Type of the tabs, only card and line types are avaialable at this
    moment.

- wrapperStyle (dict; optional):
    Inline CSS style of the entire wrapper if itemContent is set to
    False."""
    _children_props = ['items[].label', 'items[].children']
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaTabs'
    @_explicitize_args
    def __init__(self, children=None, items=Component.UNDEFINED, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, type=Component.UNDEFINED, size=Component.UNDEFINED, defaultActiveKey=Component.UNDEFINED, activeKey=Component.UNDEFINED, disabledTabKeys=Component.UNDEFINED, tabPosition=Component.UNDEFINED, centered=Component.UNDEFINED, tabBarGutter=Component.UNDEFINED, itemContent=Component.UNDEFINED, wrapperStyle=Component.UNDEFINED, childCardBorder=Component.UNDEFINED, childCardStyle=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'activeKey', 'centered', 'childCardBorder', 'childCardStyle', 'className', 'defaultActiveKey', 'disabledTabKeys', 'itemContent', 'items', 'size', 'style', 'tabBarGutter', 'tabPosition', 'type', 'wrapperStyle']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'activeKey', 'centered', 'childCardBorder', 'childCardStyle', 'className', 'defaultActiveKey', 'disabledTabKeys', 'itemContent', 'items', 'size', 'style', 'tabBarGutter', 'tabPosition', 'type', 'wrapperStyle']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaTabs, self).__init__(children=children, **args)



from anya_dash import *
from dash import Dash, Output, Input, State, html


app = Dash(__name__)

topNavBar = AnyaMenu(
    id='menu-demo',
    isTopNav=True,
    currentKey='anya-main',
    style={
        'fontSize': 13
    },
    menuItems=[
        {
            'component': 'Item',
            'props': {
                'key': 'anya-main',
                'title': 'Anya Main',
                'href': 'https://github.com/AnyaIp',
            }
        },
        {
            'component': 'SubMenu',
            'props': {
                'key': 'anya-sub',
                'title': 'Anya Sub'
            },
            'children': [
                {
                    'component': 'ItemGroup',
                    'props': {
                        'key': f'anya-sub-{item_group}',
                        'title': f'Anya Sub {item_group}'
                    },
                    'children': [
                        {
                            'component': 'Item',
                            'props': {
                                'key': f'anya-sub-{item_group}-{item}',
                                'title': f'Anya Sub {item_group}-{item}'
                            }
                        }
                        for item in range(1, 3)
                    ]
                }
                for item_group in range(1, 3)
            ]
        }
    ],
    mode='horizontal'
)

sideNavBar = AnyaMenu(
    id='menu-demo-side',
    isTopNav=False,
    mode='inline',
    currentKey='anya-main',
    style={
        'height': '100%'
    },
    menuItems=[
        {
            'component': 'Item',
            'props': {
                'key': 'anya-main',
                'title': 'Anya Main',
                'href': 'https://github.com/AnyaIp',
            }
        },
        {
            'component': 'SubMenu',
            'props': {
                'key': 'anya-sub',
                'title': 'Anya Sub'
            },
            'children': [
                {
                    'component': 'ItemGroup',
                    'props': {
                        'key': f'anya-sub-{item_group}',
                        'title': f'Anya Sub-{item_group}'
                    },
                    'children': [
                        {
                            'component': 'Item',
                            'props': {
                                'key': f'anya-sub-{item_group}-{item}',
                                'title': f'Anya Sub-{item_group}-{item}'
                            }
                        }
                        for item in range(1, 3)
                    ]
                }
                for item_group in range(1, 3)
            ]
        }
    ],
)

app.layout = AnyaTheme(
    [
        AnyaAffix(topNavBar),
        AnyaLayout(
            [
                AnyaSider(
                    sideNavBar,
                    theme='light',
                    collapsible=True,
                    id='anya-sider',
                    isFixed=True,
                    offsetTop=46,
                    width=300
                ),
                AnyaLayout(
                    [
                        AnyaAffix(
                            AnyaHeader(
                                'Header',
                                collapsible=True,
                                id='anya-header'
                            ),
                            offsetTop=46,
                            className='affix'
                        ),
                        AnyaContent(
                            'Content',
                            style={
                                'height': '100vh',
                                'display': 'flex',
                                'alignItems': 'center',
                                'justifyContent': 'center',
                            },
                            backgroundColor='#f3f6ff',
                            id='anya-content'
                        ),
                        AnyaFooter('Footer', textAlign='center')
                    ],
                    id='content-container'
                ),
            ],
            hasSider=True,
            style={'backgroundColor': '#fff'}
        )
    ]
)


@app.callback(
    [
        Output('anya-sider', 'collapsed'),
        Output('content-container', 'style')
    ],
    Input('anya-header', 'isClicked')
)
def collapse_sider(isClicked):
    if isClicked:
        style = {'marginLeft': 0, 'transition': '0.5s'}
    else:
        style = {'marginLeft': 300}
    return isClicked, style


if __name__ == '__main__':
    app.run_server(debug=True)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaSider(Component):
    """An AnyaSider component.
An Ant Design Sider component
See https://ant.design/components/layout

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Child components inside the layout.

- id (string; optional):
    The ID used to identify this component.

- backgroundColor (string; optional):
    Background color.

- breakpoint (a value equal to: 'xs', 'sm', 'md', 'lg', 'xl', 'xxl'; optional):
    Breakpoints of the responsive layout.

- className (string; optional):
    CSS classes to be added to the component.

- collapsed (boolean; default False):
    To set the current status.

- collapsedWidth (number; default 0):
    Width of the collapsed sidebar, by setting to 0 a special trigger
    will appear.

- collapsible (boolean; default False):
    Whether can be collapsed.

- defaultCollapsed (boolean; default False):
    To set the initial status.

- isFixed (boolean; optional):
    Whether the sider is fixed.

- offsetTop (number; optional):
    Offset from the top of the viewport (in pixels) if the sider is
    fixed.

- reverseArrow (boolean; default False):
    Reverse direction of arrow, for a sider that expands from the
    right.

- style (dict; optional):
    Inline CSS style.

- theme (a value equal to: 'light', 'dark'; default 'light'):
    Color theme of the sidebar.

- width (number | string; default 300):
    Width of the sidebar."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaSider'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, backgroundColor=Component.UNDEFINED, style=Component.UNDEFINED, collapsed=Component.UNDEFINED, defaultCollapsed=Component.UNDEFINED, collapsedWidth=Component.UNDEFINED, collapsible=Component.UNDEFINED, reverseArrow=Component.UNDEFINED, theme=Component.UNDEFINED, width=Component.UNDEFINED, breakpoint=Component.UNDEFINED, isFixed=Component.UNDEFINED, offsetTop=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'backgroundColor', 'breakpoint', 'className', 'collapsed', 'collapsedWidth', 'collapsible', 'defaultCollapsed', 'isFixed', 'offsetTop', 'reverseArrow', 'style', 'theme', 'width']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'backgroundColor', 'breakpoint', 'className', 'collapsed', 'collapsedWidth', 'collapsible', 'defaultCollapsed', 'isFixed', 'offsetTop', 'reverseArrow', 'style', 'theme', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaSider, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaCol(Component):
    """An AnyaCol component.
An Antd Design Col component
https://ant.design/components/grid

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content.

- id (string; optional):
    Id of the col.

- className (string | dict; optional):
    CSS classname of the col.

- flex (string | number; optional):
    Flex layout style.

- lg (dict | number; optional):
    screen ≥ 992px, could be a span value or an object containing
    above props.

- md (dict | number; optional):
    screen ≥ 768px, could be a span value or an object containing
    above props.

- offset (number; default 0):
    The number of cells to offset Col from the left.

- order (number; default 0):
    Raster order.

- sm (dict | number; optional):
    screen ≥ 576px, could be a span value or an object containing
    above props.

- span (number; optional):
    Raster number of cells to occupy, 0 corresponds to.

- style (dict; optional):
    CSS style of the col.

- xl (dict | number; optional):
    screen ≥ 1200px, could be a span value or an object containing
    above props.

- xs (dict | number; optional):
    screen < 576px and also default setting, could be a span value or
    an object containing above props.

- xxl (dict | number; optional):
    screen ≥ 1600px, could be a span value or an object containing
    above props."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaCol'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, span=Component.UNDEFINED, offset=Component.UNDEFINED, order=Component.UNDEFINED, flex=Component.UNDEFINED, xs=Component.UNDEFINED, sm=Component.UNDEFINED, md=Component.UNDEFINED, lg=Component.UNDEFINED, xl=Component.UNDEFINED, xxl=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'flex', 'lg', 'md', 'offset', 'order', 'sm', 'span', 'style', 'xl', 'xs', 'xxl']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'flex', 'lg', 'md', 'offset', 'order', 'sm', 'span', 'style', 'xl', 'xs', 'xxl']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaCol, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaModal(Component):
    """An AnyaModal component.
An Ant Design Modal component
See https://ant.design/components/modal

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Child components.

- id (string; optional):
    The ID used to identify this component.

- bodyStyle (dict; optional):
    Body style.

- className (string | dict; optional):
    CSS classes to be added to the component.

- closable (boolean; default True):
    Whether the modal is closable.

- closeIconType (a value equal to: 'default', 'outlined', 'two-tone'; default 'default'):
    Close icon type.

- style (dict; optional):
    Inline CSS style.

- title (a list of or a singular dash component, string or number; optional):
    Title.

- transitionType (a value equal to: 'none', 'fade', 'zoom', 'zoom-big', 'zoom-big-fast', 'slide-up', 'slide-down', 'slide-left', 'slide-right', 'move-up', 'move-down', 'move-left', 'move-right'; default 'fade'):
    Transition animation:
    'fade'、'zoom'、'zoom-big'、'zoom-big-fast'、'zoom-up'、
    'zoom-down'、'zoom-left'、'zoom-right'、'slide-up'、'slide-down'、'slide-left'、
    'slide-right'、'move-up'、'move-down'、'move-left'、'move-right'.

- visible (boolean; default True):
    Whether the component is visible.

- width (number | string; optional):
    Width of the modal.

- zIndex (number; default 1000):
    Z-index."""
    _children_props = ['title']
    _base_nodes = ['title', 'children']
    _namespace = 'anya_dash'
    _type = 'AnyaModal'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, title=Component.UNDEFINED, visible=Component.UNDEFINED, width=Component.UNDEFINED, transitionType=Component.UNDEFINED, closable=Component.UNDEFINED, closeIconType=Component.UNDEFINED, zIndex=Component.UNDEFINED, bodyStyle=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'bodyStyle', 'className', 'closable', 'closeIconType', 'style', 'title', 'transitionType', 'visible', 'width', 'zIndex']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'bodyStyle', 'className', 'closable', 'closeIconType', 'style', 'title', 'transitionType', 'visible', 'width', 'zIndex']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaModal, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaSpace(Component):
    """An AnyaSpace component.
An Ant Design Space component
See https://ant.design/components/space

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Child components inside the space.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- align (a value equal to: 'start', 'end', 'center', 'baseline'; default 'start'):
    Config item align. start | end |center |baseline.

- className (string; optional):
    CSS classes to be added to the component.

- direction (a value equal to: 'vertical', 'horizontal'; default 'horizontal'):
    The space direction vertical | horizontal.

- size (a value equal to: 'small', 'middle', 'large' | number; default 'small'):
    Space Size, large, middle and small or an integer.

- style (dict; optional):
    Inline CSS style.

- wrap (boolean; default False):
    Auto wrap line, when horizontal effective."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaSpace'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, size=Component.UNDEFINED, align=Component.UNDEFINED, direction=Component.UNDEFINED, wrap=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'align', 'className', 'direction', 'size', 'style', 'wrap']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'align', 'className', 'direction', 'size', 'style', 'wrap']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaSpace, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaInputNumber(Component):
    """An AnyaInputNumber component.
An Ant Design InputNumber component
See https://ant.design/components/input-number
Adapted from feffery-antd-components

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- addonAfter (a list of or a singular dash component, string or number; optional):
    The label text displayed after (on the right side of) the input
    field.

- addonBefore (a list of or a singular dash component, string or number; optional):
    The label text displayed before (on the left side of) the input
    field.

- bordered (boolean; default True):
    Whether has border style.

- className (string | dict; optional):
    CSS classes to be added to the component.

- controls (boolean; default True):
    Whether to show +- controls, or set custom arrows icon.

- debounceValue (number | string; optional):
    Debounce value.

- debounceWait (number; default 200):
    Debounce waiting time.

- defaultValue (number | string; optional):
    The initial value.

- disabled (boolean; default False):
    If disable the input.

- keyboard (boolean; default True):
    If enable keyboard behavior.

- max (number | string; optional):
    The min value.

- min (number | string; optional):
    The max value.

- nSubmit (number; default 0):
    No. of times submitted.

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- placeholder (string; optional):
    Placeholder.

- precision (number; optional):
    The precision of input value. Will use formatter when config of
    formatter.

- prefix (a list of or a singular dash component, string or number; optional):
    The prefix icon for the Input.

- readOnly (boolean; optional):
    Read only.

- size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
    The height of input box.

- status (a value equal to: 'error', 'warning'; optional):
    Status.

- step (number | string; optional):
    The number to which the current value is increased or decreased.
    It can be an integer or decimal.

- stringMode (boolean; default False):
    Set value as string to support high precision decimals. Will
    return string value by onChange.

- style (dict; optional):
    Inline CSS style.

- value (number | string; optional):
    The current value."""
    _children_props = ['addonBefore', 'addonAfter', 'prefix']
    _base_nodes = ['addonBefore', 'addonAfter', 'prefix', 'children']
    _namespace = 'anya_dash'
    _type = 'AnyaInputNumber'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, addonBefore=Component.UNDEFINED, addonAfter=Component.UNDEFINED, prefix=Component.UNDEFINED, controls=Component.UNDEFINED, keyboard=Component.UNDEFINED, min=Component.UNDEFINED, max=Component.UNDEFINED, step=Component.UNDEFINED, precision=Component.UNDEFINED, stringMode=Component.UNDEFINED, disabled=Component.UNDEFINED, size=Component.UNDEFINED, bordered=Component.UNDEFINED, placeholder=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, debounceValue=Component.UNDEFINED, debounceWait=Component.UNDEFINED, nSubmit=Component.UNDEFINED, status=Component.UNDEFINED, readOnly=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'addonAfter', 'addonBefore', 'bordered', 'className', 'controls', 'debounceValue', 'debounceWait', 'defaultValue', 'disabled', 'keyboard', 'max', 'min', 'nSubmit', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'precision', 'prefix', 'readOnly', 'size', 'status', 'step', 'stringMode', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'addonAfter', 'addonBefore', 'bordered', 'className', 'controls', 'debounceValue', 'debounceWait', 'defaultValue', 'disabled', 'keyboard', 'max', 'min', 'nSubmit', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'precision', 'prefix', 'readOnly', 'size', 'status', 'step', 'stringMode', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaInputNumber, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaSwitch(Component):
    """An AnyaSwitch component.
An Ant Design Swith component
See https://ant.design/components/switch

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- checked (boolean; optional):
    Determine whether the Switch is checked.

- checkedChildren (a list of or a singular dash component, string or number; optional):
    The content to be shown when the state is checked.

- className (string; optional):
    CSS classes to be added to the component.

- disabled (boolean; default False):
    Whether to disable the switch component.

- loading (boolean; default False):
    Loading state of switch.

- persisted_props (list of a value equal to: 'checked's; default ['checked']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- size (a value equal to: 'default', 'small'; default 'default'):
    The size of the Switch, options: default small.

- style (dict; optional):
    Inline CSS style.

- unCheckedChildren (a list of or a singular dash component, string or number; optional):
    The content to be shown when the state is unchecked."""
    _children_props = ['checkedChildren', 'unCheckedChildren']
    _base_nodes = ['checkedChildren', 'unCheckedChildren', 'children']
    _namespace = 'anya_dash'
    _type = 'AnyaSwitch'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, disabled=Component.UNDEFINED, checked=Component.UNDEFINED, checkedChildren=Component.UNDEFINED, unCheckedChildren=Component.UNDEFINED, size=Component.UNDEFINED, loading=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'checked', 'checkedChildren', 'className', 'disabled', 'loading', 'persisted_props', 'persistence', 'persistence_type', 'size', 'style', 'unCheckedChildren']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'checked', 'checkedChildren', 'className', 'disabled', 'loading', 'persisted_props', 'persistence', 'persistence_type', 'size', 'style', 'unCheckedChildren']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaSwitch, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaCheckbox(Component):
    """An AnyaCheckbox component.
An Ant Design Checkbox component
See https://ant.design/components/checkbox
Adapted from feffery-antd-components

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Text content of the inline text.

- id (string; optional):
    Component id.

- checked (boolean; default False):
    If the box is checked.

- className (string | dict; optional):
    CSS class name.

- disabled (boolean; default False):
    If disable checkbox.

- indeterminate (boolean; default False):
    The indeterminate checked state of checkbox.

- label (a list of or a singular dash component, string or number; optional):
    Label of the checkbox.

- persisted_props (list of a value equal to: 'checked's; default ['checked']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- style (dict; optional):
    Inline CSS style."""
    _children_props = ['label']
    _base_nodes = ['label', 'children']
    _namespace = 'anya_dash'
    _type = 'AnyaCheckbox'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, disabled=Component.UNDEFINED, label=Component.UNDEFINED, checked=Component.UNDEFINED, indeterminate=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'checked', 'className', 'disabled', 'indeterminate', 'label', 'persisted_props', 'persistence', 'persistence_type', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'checked', 'className', 'disabled', 'indeterminate', 'label', 'persisted_props', 'persistence', 'persistence_type', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaCheckbox, self).__init__(children=children, **args)



from .AnyaButton import AnyaButton
from .AnyaIcon import AnyaIcon
from .AnyaTag import AnyaTag
from .AnyaExecuteJs import AnyaExecuteJs
from .AnyaTheme import AnyaTheme
from .AnyaCard import AnyaCard
from .AnyaCollapse import AnyaCollapse
from .AnyaModal import AnyaModal
from .AnyaTable import AnyaTable
from .AnyaTabs import AnyaTabs
from .AnyaCheckbox import AnyaCheckbox
from .AnyaCheckboxGroup import AnyaCheckboxGroup
from .AnyaDateRangePicker import AnyaDateRangePicker
from .AnyaInput import AnyaInput
from .AnyaInputNumber import AnyaInputNumber
from .AnyaRadioGroup import AnyaRadioGroup
from .AnyaSelect import AnyaSelect
from .AnyaSlider import AnyaSlider
from .AnyaSwitch import AnyaSwitch
from .AnyaCol import AnyaCol
from .AnyaRow import AnyaRow
from .AnyaAffix import AnyaAffix
from .AnyaContent import AnyaContent
from .AnyaDivider import AnyaDivider
from .AnyaFooter import AnyaFooter
from .AnyaHeader import AnyaHeader
from .AnyaLayout import AnyaLayout
from .AnyaSider import AnyaSider
from .AnyaSpace import AnyaSpace
from .AnyaMenu import AnyaMenu
from .AnyaParagraph import AnyaParagraph
from .AnyaText import AnyaText
from .AnyaTitle import AnyaTitle

__all__ = [
    "AnyaButton",
    "AnyaIcon",
    "AnyaTag",
    "AnyaExecuteJs",
    "AnyaTheme",
    "AnyaCard",
    "AnyaCollapse",
    "AnyaModal",
    "AnyaTable",
    "AnyaTabs",
    "AnyaCheckbox",
    "AnyaCheckboxGroup",
    "AnyaDateRangePicker",
    "AnyaInput",
    "AnyaInputNumber",
    "AnyaRadioGroup",
    "AnyaSelect",
    "AnyaSlider",
    "AnyaSwitch",
    "AnyaCol",
    "AnyaRow",
    "AnyaAffix",
    "AnyaContent",
    "AnyaDivider",
    "AnyaFooter",
    "AnyaHeader",
    "AnyaLayout",
    "AnyaSider",
    "AnyaSpace",
    "AnyaMenu",
    "AnyaParagraph",
    "AnyaText",
    "AnyaTitle"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaRow(Component):
    """An AnyaRow component.
An Antd Design Row component
https://ant.design/components/grid

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content.

- id (string; optional):
    Id of the row.

- align (a value equal to: 'top', 'middle', 'bottom', 'stretch'; default 'middle'):
    Vertical alignment: top | middle | bottom | stretch.

- className (string | dict; optional):
    CSS classname of the row.

- gutter (dict; optional):
    Spacing between grids, could be a number or a object like { xs: 8,
    sm: 16, md: 24}. Or you can use array to make horizontal and
    vertical spacing work at the same time [horizontal, vertical].

    `gutter` is a number | list of numbers | dict with keys:

    - lg (number; optional)

    - md (number; optional)

    - sm (number; optional)

    - xl (number; optional)

    - xs (number; optional)

    - xxl (number; optional)

- justify (a value equal to: 'start', 'end', 'center', 'space-around', 'space-between'; optional):
    Horizontal arrangement.

- style (dict; optional):
    CSS style of the row.

- wrap (boolean; optional):
    Auto wrap line."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaRow'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, align=Component.UNDEFINED, gutter=Component.UNDEFINED, justify=Component.UNDEFINED, wrap=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'align', 'className', 'gutter', 'justify', 'style', 'wrap']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'align', 'className', 'gutter', 'justify', 'style', 'wrap']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaRow, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaSlider(Component):
    """An AnyaSlider component.
An Ant Design slider component
See https://ant.design/components/slider
Adapted from feffery-antd-components

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    CSS classes to be added to the component.

- defaultValue (number | list of numbers; optional):
    Default value.

- disabled (boolean; default False):
    Disable the component.

- marks (dict with strings as keys and values of type string; optional):
    Tick mark of Slider, type of key must be number, and must in
    closed interval [min, max], each mark can declare its own style.

- max (number; default 100):
    The minimum value the slider can slide to.

- min (number; default 0):
    The maximum value the slider can slide to.

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    The DOM container of the Tooltip, the default behavior is to
    create a div element in body.

- railStyle (dict; optional):
    The style of slider rail (the background).

- range (boolean; default False):
    Dual thumb mode.

- step (number; default 1):
    The granularity the slider can step through values. Must greater
    than 0, and be divided by (max - min) . When marks no None, step
    can be None.

- style (dict; optional):
    Inline CSS style.

- tooltipPrefix (string; default ''):
    Tooltip prefix.

- tooltipSuffix (string; default ''):
    Tooltip suffix.

- tooltipVisible (boolean; optional):
    Whether to display tooltop.

- value (number | list of numbers; optional):
    Value.

- vertical (boolean; default False):
    Vertical mode."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaSlider'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, railStyle=Component.UNDEFINED, vertical=Component.UNDEFINED, range=Component.UNDEFINED, min=Component.UNDEFINED, max=Component.UNDEFINED, step=Component.UNDEFINED, marks=Component.UNDEFINED, tooltipVisible=Component.UNDEFINED, tooltipPrefix=Component.UNDEFINED, tooltipSuffix=Component.UNDEFINED, disabled=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, popupContainer=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'defaultValue', 'disabled', 'marks', 'max', 'min', 'persisted_props', 'persistence', 'persistence_type', 'popupContainer', 'railStyle', 'range', 'step', 'style', 'tooltipPrefix', 'tooltipSuffix', 'tooltipVisible', 'value', 'vertical']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'defaultValue', 'disabled', 'marks', 'max', 'min', 'persisted_props', 'persistence', 'persistence_type', 'popupContainer', 'railStyle', 'range', 'step', 'style', 'tooltipPrefix', 'tooltipSuffix', 'tooltipVisible', 'value', 'vertical']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaSlider, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaTable(Component):
    """An AnyaTable component.
An Ant Design Table component
See https://ant.design/components/table

Keyword arguments:

- id (string; optional):
    The ID used to identify this component.

- bordered (boolean; optional):
    Bordered.

- cellUpdateOptimize (boolean; default True):
    Whether to allow cell content rendering.

- className (string | dict; optional):
    CSS classes to be added to the component.

- columns (list of dicts; optional):
    Columns.

    `columns` is a list of dicts with keys:

    - align (a value equal to: 'left', 'center', 'right'; optional)

    - className (dict; optional)

    - colSpan (number; optional)

    - colSpanRow (dict; optional)

    - dataIndex (string; required)

    - ellipsis (boolean | number | string | dict | list; optional)

    - filterResetToDefaultFilteredValue (boolean; optional)

    - fixed (a value equal to: 'left', 'right'; optional)

    - group (string | list of strings; optional)

    - hidden (boolean; optional)

    - key (string; optional)

    - onCell (boolean | number | string | dict | list; optional)

    - render (boolean | number | string | dict | list; optional)

    - renderOptions (dict; optional)

        `renderOptions` is a dict with keys:

        - renderType (a value equal to: 'row-merge'; optional)

    - rowSpan (dict; optional)

    - sorter (boolean | number | string | dict | list; optional)

    - title (a list of or a singular dash component, string or number; required)

    - width (number | string; optional)

- data (list of dicts; optional):
    Column data.

    `data` is a list of dicts with strings as keys and values of type
    list of boolean | number | string | dict | lists | a list of or a
    singular dash component, string or number | string | number | dict
    with keys:

    - content (number | string; optional)

    - key (string; optional)

    - rowSpan (number; optional)

- maxHeight (number; optional):
    Set max height.

- maxWidth (number; optional):
    Set max width.

- pagination (dict; default {    defaultPageSize: 20,    hideOnSinglePage: True,    showSizeChanger: False}):
    Config of pagination. You can ref table pagination config or full
    pagination document, hide it by setting it to False.

    `pagination` is a dict with keys:

    - current (number; optional)

    - disabled (boolean; optional)

    - hideOnSinglePage (boolean; optional)

    - pageSize (number; optional)

    - pageSizeOptions (list of numbers; optional)

    - position (a value equal to: 'topLeft', 'topCenter', 'topRight', 'bottomLeft', 'bottomCenter', 'bottomRight'; optional)

    - showQuickJumper (boolean; optional)

    - showSizeChanger (boolean; optional)

    - showTotal (boolean; optional)

    - showTotalPrefix (string; optional)

    - showTotalSuffix (string; optional)

    - simple (boolean; optional)

    - size (a value equal to: 'default', 'small'; optional)

    - total (number; optional) | boolean | dict

- size (a value equal to: 'small', 'default', 'large'; default 'small'):
    Size.

- style (dict; optional):
    Inline CSS style."""
    _children_props = ['columns[].title', 'data[]{}']
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaTable'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, columns=Component.UNDEFINED, data=Component.UNDEFINED, bordered=Component.UNDEFINED, maxHeight=Component.UNDEFINED, maxWidth=Component.UNDEFINED, size=Component.UNDEFINED, pagination=Component.UNDEFINED, cellUpdateOptimize=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'bordered', 'cellUpdateOptimize', 'className', 'columns', 'data', 'maxHeight', 'maxWidth', 'pagination', 'size', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'bordered', 'cellUpdateOptimize', 'className', 'columns', 'data', 'maxHeight', 'maxWidth', 'pagination', 'size', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaTable, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaCard(Component):
    """An AnyaCard component.
An Ant Design Card component
See https://ant.design/components/card

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content to be displayed on the card.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- bodyStyle (dict; optional):
    Inline CSS style of card body.

- className (string; optional):
    CSS classes to be added to the component.

- coverImgSrc (string; optional):
    Url of the cover image if applicable. The extra link is not
    avaialbe when a cover image is used.

- extraLinkHref (string; optional):
    Extra link to be displayed on the top right corner - href.

- extraLinkStyle (dict; optional):
    Extra link to be displayed on the top right corner - CSS style.

- extraLinkText (string; optional):
    Extra link to be displayed on the top right corner - text. It will
    not be displayed if the title is missing or a cover image is
    enabled.

- headStyle (dict; optional):
    Inline CSS style of card header.

- hoverable (boolean; default False):
    Lift up when hovering card.

- imgStyle (dict; optional):
    CSS style of cover image.

- size (a value equal to: 'small', 'default'; default 'default'):
    Size of card. default | small.

- style (dict; optional):
    Inline CSS style.

- title (string; optional):
    Title of the card.

- type (string; optional):
    Card style type, can be set to inner or not set."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaCard'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, type=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, headStyle=Component.UNDEFINED, bodyStyle=Component.UNDEFINED, size=Component.UNDEFINED, title=Component.UNDEFINED, extraLinkText=Component.UNDEFINED, extraLinkHref=Component.UNDEFINED, extraLinkStyle=Component.UNDEFINED, hoverable=Component.UNDEFINED, coverImgSrc=Component.UNDEFINED, imgStyle=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'bodyStyle', 'className', 'coverImgSrc', 'extraLinkHref', 'extraLinkStyle', 'extraLinkText', 'headStyle', 'hoverable', 'imgStyle', 'size', 'style', 'title', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'bodyStyle', 'className', 'coverImgSrc', 'extraLinkHref', 'extraLinkStyle', 'extraLinkText', 'headStyle', 'hoverable', 'imgStyle', 'size', 'style', 'title', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaCard, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaFooter(Component):
    """An AnyaFooter component.
An Ant Design Sider component
See https://ant.design/components/layout

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Child components inside the layout.

- className (string; optional):
    CSS classes to be added to the component.

- style (dict; optional):
    Inline CSS style.

- textAlign (a value equal to: 'start', 'center', 'end', 'justify'; default 'center'):
    textAlign, in start|center|end|justify."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaFooter'
    @_explicitize_args
    def __init__(self, children=None, className=Component.UNDEFINED, style=Component.UNDEFINED, textAlign=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'className', 'style', 'textAlign']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'className', 'style', 'textAlign']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaFooter, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaDivider(Component):
    """An AnyaDivider component.
An Ant Design Divder component
See https://ant.design/components/divider
Adapted from feffery-antd-components

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Text content of the inline text.

- id (string; optional):
    Component id.

- className (string | dict; optional):
    CSS class name.

- direction (a value equal to: "horizontal", "vertical"; default "horizontal"):
    Direction of the divider. Possible values are 'horizontal' and
    'vertical'. Default is 'horizontal'.

- fontColor (string; optional):
    Color of the inline text. Accepts valid color values in CSS.

- fontFamily (string; optional):
    Font family of the inline text. Accepts valid font-family values
    in CSS.

- fontSize (string; optional):
    Font size of the inline text. Accepts valid font-size values in
    CSS.

- fontStyle (string; optional):
    Font style of the inline text. Accepts valid font-style values in
    CSS.

- fontWeight (string; optional):
    Font weight of the inline text. Accepts valid font-weight values
    in CSS.

- innerTextOrientation (a value equal to: "left", "center", "right"; default "left"):
    Text alignment of the inline text. Possible values are 'left',
    'center', and 'right'. Default is 'center'.

- isDashed (boolean; default False):
    Whether to render the divider as dashed line. True for dashed
    line, False for solid line. Default is False.

- lineColor (string; default "lightgrey"):
    Color of the divider. Accepts valid color values in CSS."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaDivider'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, innerTextOrientation=Component.UNDEFINED, isDashed=Component.UNDEFINED, direction=Component.UNDEFINED, fontSize=Component.UNDEFINED, lineColor=Component.UNDEFINED, fontStyle=Component.UNDEFINED, fontWeight=Component.UNDEFINED, fontFamily=Component.UNDEFINED, fontColor=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'direction', 'fontColor', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'innerTextOrientation', 'isDashed', 'lineColor']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'direction', 'fontColor', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'innerTextOrientation', 'isDashed', 'lineColor']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaDivider, self).__init__(children=children, **args)



from anya_dash import *
from dash import Dash, Output, Input, State, html, ALL, ctx
import pandas as pd


df = pd.read_csv('test.csv').head(50)
df = df[['First Name', 'Last Name', 'Sex', 'Email', 'Job Title']]
df.columns = ['first_name', 'last_name', 'sex', 'email', 'title']


def df_to_source(
    df,
    rename={}
):
    cols = []
    for col in df.columns:
        col_dt = {'dataIndex': col}
        if col in rename:
            col_dt.update(rename[col])
        else:
            col_dt.update({'title': col})
        cols.append(col_dt)
    df.insert(0, 'key', range(1, len(df) + 1))
    data = df.to_dict('records')
    return cols, data


cols, data = df_to_source(df, rename={
    'age': {'align': 'center', 'title': 'Age'},
    'sex': {'title': 'Sex', 'align': 'center'},
    'email': {'title': 'Email'},
    'title': {'title': 'Job Title'},
    'first_name': {'title': 'First Name'},
    'last_name': {'title': 'Last Name'}
})

cols2 = [
    {'dataIndex': 'first_name', 'title': 'Name', 'colSpan': 2,
        'rowSpan': {0: 2, 1: 0}, 'colSpanRow': {2: 1}},
    {'dataIndex': 'last_name', 'title': 'Last Name', 'colSpan': 0,
        'rowSpan': {0: 2, 1: 0}, 'colSpanRow': {2: 1}},
    {'dataIndex': 'sex', 'title': 'Sex', 'rowSpan': {
        0: 2, 1: 0}, 'align': 'center', 'colSpanRow': {2: 2}},
    {'dataIndex': 'title', 'title': 'Job Title',
        'rowSpan': {3: 2, 4: 0}, 'colSpanRow': {2: 0}}
]

data2 = [
    {'key': 'sh', 'first_name': 'Shelby', 'last_name': 'Terrell',
     'sex': AnyaTag('Male', color='blue'), 'title': 'Games developer'},
    {'key': 'se', 'title': 'Phytotherapist'},
    {'key': 'kr', 'first_name': 'Kristine',
        'last_name': 'Travis', 'sex': '', 'title': 'Homeopath', },
    {'key': 'ye', 'first_name': 'Yesenia', 'last_name': 'Martinez',
        'sex': AnyaTag('Male', color='blue'),  'title': 'Market researcher'},
    {'key': 'lo', 'first_name': 'Marry', 'last_name': 'Todd',
        'sex': AnyaTag('Female', color='pink'), 'title': 'Market researcher'}
]

app = Dash(__name__)
app.layout = AnyaTheme(
    AnyaRow(
        AnyaCol(
            [
                AnyaTitle('Basic Usage', level=4),
                AnyaTable(
                    columns=cols,
                    data=data,
                    pagination={
                        'pageSize': 5,
                        'hideOnSinglePag': True,
                        'showSizeChanger': False,
                        'showTotal': True
                        # 'position': 'topRight'
                    },
                    size='small',
                    bordered=True,
                    id='table-1',
                ),
                html.Hr(),
                AnyaTitle('colSpan & rowSpan', level=4),
                AnyaTable(
                    columns=cols2,
                    data=data2,
                    pagination=False,
                    size='small',
                    bordered=True
                ),
            ],
            lg={'span': 18, 'offset': 3},
            md={'span': 20, 'offset': 2},
            xs=24,
            style={
                'backgroundColor': '#fff',
                'padding': '32px',
                'minHeight': '100vh'
            }
        ),
        style={'backgroundColor': '#f3f6ff'}
    )
)


if __name__ == '__main__':
    app.run_server(debug=True)



from anya_dash import *
from dash import Dash, Output, Input, State, html


app = Dash(__name__)


tags = [
    AnyaTag(
        children=color,
        color=color
    )
    for color in [
        'magenta',
        'red',
        'volcano',
        'orange',
        'gold',
        'lime',
        'green',
        'cyan',
        'blue',
        'geekblue',
        'purple'
    ]
]

tags += [AnyaTag('linked tag', color='#6366f1',
                 href='https://github.com/AnyaIp')]

app.layout = AnyaTheme(
    [
        AnyaLayout(
            [
                AnyaContent(
                    AnyaRow(
                        AnyaCol(
                            html.Div(
                                [
                                    AnyaTitle('Tags', level=3),
                                    AnyaSpace(
                                        tags,
                                        wrap=True,
                                        size='small'
                                    ),
                                    html.Hr(),
                                    AnyaTitle('Buttons', level=3),
                                    AnyaSpace(
                                        [
                                            AnyaButton('primary', type='primary'),
                                            AnyaButton('dagner', danger=True),
                                            AnyaButton('success', success=True),
                                            AnyaButton('ghost', type='ghost'),
                                            AnyaButton('linked button', info=True, href='https://github.com/AnyaIp'),
                                            AnyaButton('click test', pink=True, id='click-btn'),
                                            AnyaButton('No. of clicks: 0', type='dashed', id='nclicks-btn', n_clicks=0),
                                        ],
                                        wrap=True,
                                        size='small'
                                    ),
                                    html.Hr(),
                                    AnyaTitle('Icons', level=3),
                                    AnyaSpace(
                                        [
                                            AnyaIcon(icon='FullscreenOutlined', style={'fontSize': '20px', 'color': '#6366f1'}),
                                            AnyaIcon(icon='HeartTwoTone', style={'fontSize': '20px'}),
                                            AnyaIcon(icon='CalendarOutlined', style={'fontSize': '20px', 'color': '#6366f1'})
                                        ],
                                        wrap=True,
                                        size='small'          
                                    )

                                ]
                            ),
                            lg={'span': 18, 'offset': 3},
                            md={'span': 20, 'offset': 2},
                            xs=24,
                            style={
                                'backgroundColor': '#fff',
                                'height': '100vh',
                                'padding': '16px'
                            }
                        )
                    ),
                    backgroundColor='#f3f6ff',
                    id='anya-content'
                ),
                AnyaFooter('Footer', textAlign='center')
            ],
            id='content-container',
            style={'backgroundColor': '#fff'}
        ),

    ]
)

@app.callback(
    Output('nclicks-btn', 'children'),
    Input('click-btn', 'n_clicks'),
    prevent_initial_call=True
)
def count_click(val):
    return 'No. of clicks: {}'.format(val)


if __name__ == '__main__':
    app.run_server(debug=True)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaRadioGroup(Component):
    """An AnyaRadioGroup component.
An Ant Design Divder component
See https://ant.design/components/radio
Adapted from feffery-antd-components

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- buttonStyle (a value equal to: 'outline', 'solid'; default 'outline'):
    The style type of radio button, outline | solid.

- className (string; optional):
    CSS classes to be added to the component.

- defaultValue (string | number; optional):
    Default selected value.

- direction (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
    Direction of the radio group.

- disabled (boolean; default False):
    Disable the radio group.

- optionType (a value equal to: 'default', 'button'; default 'default'):
    Set Radio optionType.

- options (list of dicts; optional):
    Array of options.

    `options` is a list of dicts with keys:

    - disabled (boolean; optional)

    - label (a list of or a singular dash component, string or number; optional)

    - value (string | number; optional)

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- size (a value equal to: 'large', 'middle', 'small'; default 'small'):
    Size of the radio group.

- style (dict; optional):
    Inline CSS style.

- value (string | number; optional):
    Selected value."""
    _children_props = ['options[].label']
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaRadioGroup'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, direction=Component.UNDEFINED, options=Component.UNDEFINED, disabled=Component.UNDEFINED, size=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, optionType=Component.UNDEFINED, buttonStyle=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'buttonStyle', 'className', 'defaultValue', 'direction', 'disabled', 'optionType', 'options', 'persisted_props', 'persistence', 'persistence_type', 'size', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'buttonStyle', 'className', 'defaultValue', 'direction', 'disabled', 'optionType', 'options', 'persisted_props', 'persistence', 'persistence_type', 'size', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaRadioGroup, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaButton(Component):
    """An AnyaButton component.
An Ant Design Button component
See https://ant.design/components/button

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content to be displayed on the button.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    CSS classes to be added to the component.

- danger (boolean; default False):
    Set the danger status of button.

- debounceWait (number; default 200):
    Used to set the debounce waiting duration (in milliseconds) for
    n_clicks listener update; default is 0.

- disabled (boolean; default False):
    Setting whether the button should be rendered as a disabled state,
    default is False.

- href (string; optional):
    href if the button is set to a link.

- info (boolean; optional):
    if the button is an info button (blue).

- n_clicks (number; default 0):
    Recording the number of times the button has been clicked since
    rendering, default is 0.

- pink (boolean; optional):
    if the button is in pink.

- shape (a value equal to: 'circle', 'round'; optional):
    Setting the shape of the button (circle: circle, round: rounded
    rectangle; default is not set, i.e., normal rectangle).

- size (a value equal to: 'small', 'middle', 'large'; default 'small'):
    Setting the size of the button, available options are 'small',
    'middle', and 'large'; default is 'middle'.

- style (dict; optional):
    Inline CSS style.

- success (boolean; default False):
    Set the success status of button, green.

- target (string; default '_blank'):
    target of the link, e.g., \"_blank\".

- type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; default 'primary'):
    Setting the overall style of the button (optional options are
    primary, ghost dashed, link, text, default; default is default)."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaButton'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, type=Component.UNDEFINED, danger=Component.UNDEFINED, success=Component.UNDEFINED, pink=Component.UNDEFINED, info=Component.UNDEFINED, href=Component.UNDEFINED, target=Component.UNDEFINED, disabled=Component.UNDEFINED, shape=Component.UNDEFINED, size=Component.UNDEFINED, n_clicks=Component.UNDEFINED, debounceWait=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'danger', 'debounceWait', 'disabled', 'href', 'info', 'n_clicks', 'pink', 'shape', 'size', 'style', 'success', 'target', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'danger', 'debounceWait', 'disabled', 'href', 'info', 'n_clicks', 'pink', 'shape', 'size', 'style', 'success', 'target', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaButton, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaContent(Component):
    """An AnyaContent component.
An Ant Design Content component
See https://ant.design/components/layout

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Child components inside the layout.

- id (string; optional):
    The ID used to identify this component.

- backgroundColor (string; default '#fff'):
    Background color.

- className (string; optional):
    CSS classes to be added to the component.

- contentStyle (dict; optional):
    Inline CSS style for the content.

- style (dict; optional):
    Inline CSS style."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaContent'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, backgroundColor=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, contentStyle=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'backgroundColor', 'className', 'contentStyle', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'backgroundColor', 'className', 'contentStyle', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaContent, self).__init__(children=children, **args)



from anya_dash import *
from dash import Dash, Output, Input, State, html
from dash.exceptions import PreventUpdate


app = Dash(__name__)
app.layout = AnyaTheme(
    AnyaRow(
        AnyaCol(
            [
                AnyaSpace(
                    [
                        AnyaButton('Open Modal', type='primary', id='modal-btn'),
                        AnyaButton('Execute JS', type='primary', id='js-btn'),
                        AnyaExecuteJs(id='execute-js')
                    ]
                ),
                AnyaModal(
                    'Modal Content',
                    id='modal',
                    title='Title',
                    visible=False
                ),
                AnyaRow(
                    AnyaCol(
                        AnyaTabs(
                            items=[
                                {
                                    'key': f'tab{i}',
                                    'label': f'tab{i}'
                                }
                                for i in range(1, 6)
                            ],
                            id='tabs',
                            defaultActiveKey='tab1',
                            children=html.Div(id='activeTab'),
                            wrapperStyle={
                                'padding': '20px',
                                'width': '600px'
                            },
                            childCardStyle={
                                'backgroundColor': '#efeffb',
                                'aligItems': 'center',
                                'justifyContent': 'center',
                                'display': 'flex',
                            }
                        ),
                        span=12
                    )
                ),
                AnyaRow(
                    [
                        AnyaCol(
                            AnyaCard(
                                children='Card without any title',
                                style={'height': '130px'}
                            ),
                            span=8
                        ),
                        AnyaCol(
                            AnyaCard(
                                title='Title',
                                children='Card with a title',
                                style={'height': '130px'},
                                size='small',
                                extraLinkHref='https://github.com/AnyaIp',
                                extraLinkText='Anya',
                            ),
                            span=8
                        ),
                        AnyaCol(
                            AnyaCard(
                                children='Card without external link',
                                style={'height': '130px'},
                                size='small',
                                extraLinkHref='https://github.com/AnyaIp',
                                extraLinkText='Anya',
                            ),
                            span=8
                        ),
                    ],
                    gutter=10,
                    style={'marginBottom': '10px'}
                ),
                AnyaRow(
                    [
                        AnyaCol(
                            AnyaCard(
                                'backgroundColor: #f9f9f9',
                                title='Title Ya',
                                headStyle={'backgroundColor': '#de5886', 'color': '#fff',
                                           'paddingTop': '0px', 'paddingBottom': '0px'},
                                bodyStyle={
                                    'backgroundColor': '#f9f9f9', 'height': '150px'},
                                size='small',
                                extraLinkHref='https://github.com/AnyaIp',
                                extraLinkText='Anya',
                                extraLinkStyle={'color': '#fff'}
                            ),
                            span=8
                        ),
                        AnyaCol(
                            AnyaCard(
                                children='Hoverable card with a cover image',
                                coverImgSrc='https://c4.wallpaperflare.com/wallpaper/393/423/638/anya-forger-spy-x-family-anime-girls-hd-wallpaper-preview.jpg',
                                hoverable=True
                            ),
                            span=8
                        ),
                        AnyaCol(
                            AnyaCard(
                                children='hey ya',
                                coverImgSrc='https://c4.wallpaperflare.com/wallpaper/393/423/638/anya-forger-spy-x-family-anime-girls-hd-wallpaper-preview.jpg',
                                hoverable=True,
                                title='Title Ya',
                                bodyStyle={'backgroundColor': '#fff5f7'},
                            ),
                            span=8
                        ),
                    ],
                    gutter=10,
                    style={'marginBottom': '10px'}
                ),
                AnyaRow(
                    [
                        AnyaCol(
                            AnyaCollapse(
                                AnyaParagraph(
                                    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.'
                                ),
                                bordered=False,
                                title='Collapse 1'
                            ),
                            span=8
                        ),
                        AnyaCol(
                            AnyaCollapse(
                                AnyaParagraph(
                                    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.'
                                ),
                                title='Collapse 1'
                            ),
                            span=8
                        ),
                        AnyaCol(
                            AnyaCollapse(
                                AnyaParagraph(
                                    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.'
                                ),
                                title='Collapse 1',
                                style={'backgroundColor': '#fff5f7'}
                            ),
                            span=8
                        )
                    ],
                    gutter=10
                )
            ],
            lg={'span': 18, 'offset': 3},
            md={'span': 20, 'offset': 2},
            xs=24,
            style={
                'backgroundColor': '#fff',
                'height': '100vh',
                'padding': '16px'
            }
        ),
        style={'backgroundColor': '#f3f6ff'}
    )
)


@app.callback(
    Output('activeTab', 'children'),
    Input('tabs', 'activeKey'),
    prevent_initial_call=True
)
def returnActiveTab(value):
    return value

@app.callback(
    Output('modal', 'visible'),
    Input('modal-btn', 'n_clicks'),
    prevent_initial_callback=True
)
def showModal(n_clicks):
    if n_clicks:
        return True
    raise PreventUpdate

@app.callback(
    Output('execute-js', 'jsString'),
    Input('js-btn', 'n_clicks')
)
def executejs(n_clicks):
    if n_clicks:
        return 'alert("Hello World!");'
    else:
        raise PreventUpdate
    


if __name__ == '__main__':
    app.run_server(debug=True)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaInput(Component):
    """An AnyaInput component.
An Ant Design input component
See https://ant.design/components/input
Adapted from feffery-antd-components

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- addonAfter (a list of or a singular dash component, string or number; optional):
    Ojbect (e.g, icon) after.

- addonBefore (a list of or a singular dash component, string or number; optional):
    Ojbect (e.g, icon) before.

- allowClear (boolean; default False):
    Auto clear.

- autoComplete (a value equal to: 'off', 'on'; default 'on'):
    Autocomplete.

- autoSize (dict; default False):
    Autosize.

    `autoSize` is a boolean | dict with keys:

    - maxRows (number; optional)

    - minRows (number; optional)

- bordered (boolean; default True):
    Whether to show the border of the input box.

- className (string; optional):
    CSS classes to be added to the component.

- countFormat (string; optional):
    Mode of showcount.

- debounceValue (string; optional):
    debounce value.

- debounceWait (number; default 200):
    debounce wait.

- defaultValue (string; optional):
    Default value.

- disabled (boolean; default False):
    Disable the input object.

- emptyAsNone (boolean; default False):
    Differentiate '' and None.

- maxLength (number; optional):
    Max lenghth of the entry.

- md5Value (string; optional):
    md5 value.

- mode (a value equal to: 'default', 'search', 'text-area', 'password'; default 'default'):
    Mode of the input.

- nClicksSearch (number; default 0):
    Record the number of times the search button is clicked.

- nSubmit (number; default 0):
    Record the number of times the submit button is clicked.

- passwordUseMd5 (boolean; default False):
    Passowrd mode to use md5 value.

- persisted_props (list of a value equal to: 'value', 'md5Value's; default ['value', 'md5Value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- placeholder (string; optional):
    Placehoder of the inputbox.

- prefix (a list of or a singular dash component, string or number; optional):
    Prefix inside the input box.

- readOnly (boolean; optional):
    Read only mode.

- showCount (boolean; default False):
    Whether to show character count.

- size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
    Size of the input box.

- status (a value equal to: 'error', 'warning'; optional):
    Set validation status.

- style (dict; optional):
    Inline CSS style.

- suffix (a list of or a singular dash component, string or number; optional):
    suffix inside the input box.

- value (string; optional):
    Value entered."""
    _children_props = ['addonBefore', 'addonAfter', 'prefix', 'suffix']
    _base_nodes = ['addonBefore', 'addonAfter', 'prefix', 'suffix', 'children']
    _namespace = 'anya_dash'
    _type = 'AnyaInput'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, mode=Component.UNDEFINED, autoComplete=Component.UNDEFINED, disabled=Component.UNDEFINED, size=Component.UNDEFINED, bordered=Component.UNDEFINED, placeholder=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, md5Value=Component.UNDEFINED, debounceValue=Component.UNDEFINED, passwordUseMd5=Component.UNDEFINED, debounceWait=Component.UNDEFINED, addonBefore=Component.UNDEFINED, addonAfter=Component.UNDEFINED, prefix=Component.UNDEFINED, suffix=Component.UNDEFINED, maxLength=Component.UNDEFINED, showCount=Component.UNDEFINED, countFormat=Component.UNDEFINED, autoSize=Component.UNDEFINED, nSubmit=Component.UNDEFINED, nClicksSearch=Component.UNDEFINED, status=Component.UNDEFINED, allowClear=Component.UNDEFINED, readOnly=Component.UNDEFINED, emptyAsNone=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'addonAfter', 'addonBefore', 'allowClear', 'autoComplete', 'autoSize', 'bordered', 'className', 'countFormat', 'debounceValue', 'debounceWait', 'defaultValue', 'disabled', 'emptyAsNone', 'maxLength', 'md5Value', 'mode', 'nClicksSearch', 'nSubmit', 'passwordUseMd5', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'prefix', 'readOnly', 'showCount', 'size', 'status', 'style', 'suffix', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'addonAfter', 'addonBefore', 'allowClear', 'autoComplete', 'autoSize', 'bordered', 'className', 'countFormat', 'debounceValue', 'debounceWait', 'defaultValue', 'disabled', 'emptyAsNone', 'maxLength', 'md5Value', 'mode', 'nClicksSearch', 'nSubmit', 'passwordUseMd5', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'prefix', 'readOnly', 'showCount', 'size', 'status', 'style', 'suffix', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaInput, self).__init__(**args)



from anya_dash import *
from dash import Dash, Output, Input, State, html


app = Dash(__name__)

topNavBar = AnyaMenu(
    id='menu-demo',
    isTopNav=True,
    currentKey='anya-main',
    style={
        'fontSize': 13
    },
    menuItems=[
        {
            'component': 'Item',
            'props': {
                'key': 'anya-main',
                'title': 'Anya Main',
                'href': 'https://github.com/AnyaIp',
            }
        },
        {
            'component': 'SubMenu',
            'props': {
                'key': 'anya-sub',
                'title': 'Anya Sub'
            },
            'children': [
                {
                    'component': 'ItemGroup',
                    'props': {
                        'key': f'anya-sub-{item_group}',
                        'title': f'Anya Sub {item_group}'
                    },
                    'children': [
                        {
                            'component': 'Item',
                            'props': {
                                'key': f'anya-sub-{item_group}-{item}',
                                'title': f'Anya Sub {item_group}-{item}'
                            }
                        }
                        for item in range(1, 3)
                    ]
                }
                for item_group in range(1, 3)
            ]
        }
    ],
    mode='horizontal'
)

app.layout = AnyaTheme(
    [
        AnyaAffix(topNavBar),
        AnyaLayout(
            [
                AnyaContent(
                    AnyaRow(
                        AnyaCol(
                            AnyaSpace(
                                [
                                    AnyaTitle('H1. Anya Forger (Gradient)',
                                              level=1, className='text-gradient'),
                                    AnyaParagraph(
                                        'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.'
                                    ),
                                    AnyaParagraph(
                                        'Sagittis vitae et leo duis ut diam quam nulla porttitor. In tellus integer feugiat scelerisque varius morbi enim. Tempor orci eu lobortis elementum nibh tellus molestie. Euismod lacinia at quis risus sed vulputate odio. Faucibus nisl tincidunt eget nullam non nisi. Vel elit scelerisque mauris pellentesque pulvinar pellentesque habitant. Aliquam ultrices sagittis orci a scelerisque. Molestie at elementum eu facilisis sed odio morbi. Et netus et malesuada fames ac turpis egestas maecenas pharetra. Risus ultricies tristique nulla aliquet enim. Ipsum dolor sit amet consectetur adipiscing elit pellentesque. Tellus in hac habitasse platea dictumst vestibulum rhoncus est.'
                                    ),
                                    AnyaTitle('H2. Anya Forger (Success)',
                                              level=2, type='success'),
                                    AnyaText(
                                        'Non diam phasellus vestibulum lorem sed risus ultricies tristique nulla. Bibendum neque egestas congue quisque egestas diam in arcu. Congue nisi vitae suscipit tellus mauris a diam maecenas sed.',
                                        code=True,
                                        type='success'),
                                    AnyaTitle(
                                        'H3. Anya Forger (Danger, Italic)', level=3, type='danger', italic=True),
                                    AnyaParagraph(
                                        AnyaText(
                                            'Blandit cursus risus at ultrices mi. Integer malesuada nunc vel risus commodo viverra maecenas accumsan. Habitant morbi tristique senectus et netus et malesuada fames. Interdum velit euismod in pellentesque massa placerat duis ultricies lacus. Suscipit adipiscing bibendum est ultricies integer. Lectus nulla at volutpat diam ut venenatis tellus in metus. A pellentesque sit amet porttitor eget dolor morbi non arcu. Aliquam purus sit amet luctus.',
                                            type='secondary'
                                        )
                                    ),
                                    AnyaTitle('H4. Anya Forger (Warning, Strikethrough)',
                                              level=4, strikethrough=True, type='warning'),
                                    AnyaTitle(
                                        'H5. Anya Forger (Secondary)', level=5, type='secondary')
                                ],
                                direction='vertical',
                                size=0
                            ),
                            lg={'span': 18, 'offset': 3},
                            md={'span': 20, 'offset': 2},
                            xs=24,
                            style={
                                'backgroundColor': '#fff',
                                'height': '100vh',
                                'padding': '16px'
                            }
                        )
                    ),
                    backgroundColor='#f3f6ff',
                    id='anya-content'
                ),
                AnyaFooter('Footer', textAlign='center')
            ],
            id='content-container',
            style={'backgroundColor': '#fff'}
        ),

    ]
)


if __name__ == '__main__':
    app.run_server(debug=True)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaDateRangePicker(Component):
    """An AnyaDateRangePicker component.
An Ant Date Picker component
See https://ant.design/components/date-picker
Adapted from feffery-antd-components

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- allowClear (boolean; default True):
    Allow clear.

- bordered (boolean; default True):
    Whether the box should be bordered.

- className (string; optional):
    CSS classes to be added to the component.

- defaultPickerValue (string; optional):
    Default picker value.

- defaultValue (list of strings; optional):
    Default data values.

- disabled (list of booleans; default [False, False]):
    Disable the component.

- disabledDatesStrategy (list of dicts; optional):
    Disable date strategy.

    `disabledDatesStrategy` is a list of dicts with keys:

    - mode (a value equal to: 'eq', 'ne', 'le', 'lt', 'ge', 'gt', 'in', 'not-in', 'in-enumerate-dates', 'not-in-enumerate-dates'; optional)

    - target (a value equal to: 'day', 'month', 'quarter', 'year', 'dayOfYear', 'dayOfWeek', 'specific-date'; optional)

    - value (number | string | list of numbers | list of strings; optional)

- firstDayOfWeek (number; optional):
    Define first day of week.

- format (string; optional):
    Date format.

- open (boolean; optional):
    Whether it is open.

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- picker (a value equal to: 'date', 'week', 'month', 'quarter', 'year'; default 'date'):
    Precision.

- placeholder (list of strings; optional):
    Placeholder.

- placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; default 'bottomLeft'):
    The position where the selection box pops up.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    To set the container of the floating layer, while the default is
    to create a div element in body.

- readOnly (boolean; optional):
    To set the container of the floating layer, while the default is
    to create a div element in body.

- showTime (dict; default False):
    Allow time display.

    `showTime` is a boolean | dict with keys:

    - defaultValue (list of strings; optional)

    - format (string; optional)

- size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
    Size.

- status (a value equal to: 'error', 'warning'; optional):
    Status.

- style (dict; optional):
    Inline CSS style.

- value (list of strings; optional):
    Select date trange."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaDateRangePicker'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, format=Component.UNDEFINED, picker=Component.UNDEFINED, firstDayOfWeek=Component.UNDEFINED, disabled=Component.UNDEFINED, showTime=Component.UNDEFINED, size=Component.UNDEFINED, bordered=Component.UNDEFINED, placeholder=Component.UNDEFINED, placement=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, defaultPickerValue=Component.UNDEFINED, disabledDatesStrategy=Component.UNDEFINED, open=Component.UNDEFINED, status=Component.UNDEFINED, allowClear=Component.UNDEFINED, readOnly=Component.UNDEFINED, popupContainer=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allowClear', 'bordered', 'className', 'defaultPickerValue', 'defaultValue', 'disabled', 'disabledDatesStrategy', 'firstDayOfWeek', 'format', 'open', 'persisted_props', 'persistence', 'persistence_type', 'picker', 'placeholder', 'placement', 'popupContainer', 'readOnly', 'showTime', 'size', 'status', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowClear', 'bordered', 'className', 'defaultPickerValue', 'defaultValue', 'disabled', 'disabledDatesStrategy', 'firstDayOfWeek', 'format', 'open', 'persisted_props', 'persistence', 'persistence_type', 'picker', 'placeholder', 'placement', 'popupContainer', 'readOnly', 'showTime', 'size', 'status', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaDateRangePicker, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaTheme(Component):
    """An AnyaTheme component.
An Ant Design ConfigProvider
See https://ant.design/docs/react/customize-theme

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Child components inside the space.

- colorBgContainer (string; default '#ffffff'):
    Container background color.

- colorBgLayout (string; default '#f0f2f5'):
    Layout background color.

- colorInfo (string; default '#6366f1'):
    Info color.

- colorPrimary (string; default '#6366f1'):
    Primary color.

- colorSuccess (string; default '#13c2b7'):
    Success color.

- colorTextBase (string; default '#424245'):
    Text color.

- colorWarning (string; default '#faad14'):
    Warning color.

- fontFamily (string; default "-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'"):
    Font family.

- fontSize (number; default 12):
    Font size.

- wireframe (boolean; default False):
    Wireframe."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaTheme'
    @_explicitize_args
    def __init__(self, children=None, colorPrimary=Component.UNDEFINED, colorSuccess=Component.UNDEFINED, colorWarning=Component.UNDEFINED, colorInfo=Component.UNDEFINED, colorTextBase=Component.UNDEFINED, colorBgLayout=Component.UNDEFINED, colorBgContainer=Component.UNDEFINED, fontSize=Component.UNDEFINED, fontFamily=Component.UNDEFINED, wireframe=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'colorBgContainer', 'colorBgLayout', 'colorInfo', 'colorPrimary', 'colorSuccess', 'colorTextBase', 'colorWarning', 'fontFamily', 'fontSize', 'wireframe']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'colorBgContainer', 'colorBgLayout', 'colorInfo', 'colorPrimary', 'colorSuccess', 'colorTextBase', 'colorWarning', 'fontFamily', 'fontSize', 'wireframe']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaTheme, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaCollapse(Component):
    """An AnyaCollapse component.
An Ant Design collapse component
See https://ant.design/components/collapse
Adapted from feffery-antd-components

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Children of the collapose item.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- bordered (boolean; default True):
    Whether to display the border of the collapse item.

- className (string; optional):
    CSS classes to be added to the component.

- collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
    Whether the object is collapsible.

- forceRender (boolean; default False):
    Whether to render when the object is collpased.

- ghost (boolean; default False):
    Ghost mode of the collapse item.

- isOpen (boolean; default True):
    If it is open.

- persisted_props (list of a value equal to: 'isOpen's; default ['isOpen']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- showArrow (boolean; default True):
    If False, panel will not show arrow icon. If False, collapsible
    can't be set as icon.

- style (dict; optional):
    Inline CSS style.

- title (a list of or a singular dash component, string or number; optional):
    Title of the panel."""
    _children_props = ['title']
    _base_nodes = ['title', 'children']
    _namespace = 'anya_dash'
    _type = 'AnyaCollapse'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, title=Component.UNDEFINED, isOpen=Component.UNDEFINED, bordered=Component.UNDEFINED, showArrow=Component.UNDEFINED, ghost=Component.UNDEFINED, collapsible=Component.UNDEFINED, forceRender=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'bordered', 'className', 'collapsible', 'forceRender', 'ghost', 'isOpen', 'persisted_props', 'persistence', 'persistence_type', 'showArrow', 'style', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'bordered', 'className', 'collapsible', 'forceRender', 'ghost', 'isOpen', 'persisted_props', 'persistence', 'persistence_type', 'showArrow', 'style', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaCollapse, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaText(Component):
    """An AnyaText component.
An Ant Design Text component
See https://ant.design/components/typography

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content of the paragraph.

- id (string; optional):
    Component id.

- className (string; optional):
    CSS class name.

- code (boolean; optional):
    Sets whether to render the content in code mode.

- copyable (boolean; optional):
    Sets whether the content can be quickly copied.

- disabled (boolean; optional):
    Sets whether the content is disabled.

- italic (boolean; optional):
    Sets whether the content should be italic.

- mark (boolean; optional):
    Sets whether to add mark style.

- strikethrough (boolean; optional):
    Sets whether to render the content with strikethrough mode.

- strong (boolean; optional):
    Sets whether the content should be bold.

- style (dict; optional):
    Custom CSS styles.

- type (a value equal to: 'secondary', 'success', 'warning', 'danger'; optional):
    Sets the text status type for rendering. Possible options are
    'secondary', 'success', 'warning', and 'danger'. Default is no
    status.

- underline (boolean; optional):
    Sets whether to add underline."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaText'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, code=Component.UNDEFINED, copyable=Component.UNDEFINED, strikethrough=Component.UNDEFINED, disabled=Component.UNDEFINED, mark=Component.UNDEFINED, strong=Component.UNDEFINED, italic=Component.UNDEFINED, underline=Component.UNDEFINED, type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'code', 'copyable', 'disabled', 'italic', 'mark', 'strikethrough', 'strong', 'style', 'type', 'underline']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'code', 'copyable', 'disabled', 'italic', 'mark', 'strikethrough', 'strong', 'style', 'type', 'underline']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaText, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaSelect(Component):
    """An AnyaSelect component.
An Ant Design Select component
See https://ant.design/components/select
Adapted from feffery-antd-components

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- allowClear (boolean; default True):
    Allow content to be cleared.

- autoClearSearchValue (boolean; default True):
    Whether the current search will be cleared on selecting an item.
    Only applies when mode is set to multiple or tags.

- autoSpin (boolean; default False):
    Auto spin.

- bordered (boolean; default True):
    Border of the select box.

- className (string; optional):
    CSS classes to be added to the component.

- debounceSearchValue (string; optional):
    Debounce search value.

- debounceWait (number; default 200):
    Debounce wait.

- defaultValue (string | number | list of string | numbers; optional):
    Initial selected option.

- disabled (boolean; default False):
    If disable the select component.

- dropdownAfter (a list of or a singular dash component, string or number; optional):
    Ojbect (e.g, icon) after the dropdown.

- dropdownBefore (a list of or a singular dash component, string or number; optional):
    Ojbect (e.g, icon) before the dropdown.

- emptyContent (a list of or a singular dash component, string or number; optional):
    Empty contnet.

- listHeight (number; default 256):
    List height.

- loadingEmptyContent (a list of or a singular dash component, string or number; default <div style={{display: 'flex', justifyContent: 'center'}}>    <Spin /></div>):
    Load empty content.

- maxTagCount (number | a value equal to: 'responsive'; optional):
    Max tag count.

- mode (a value equal to: 'multiple', 'tags'; optional):
    Selection mode.

- optionFilterMode (a value equal to: 'case-insensitive', 'case-sensitive', 'regex'; default 'case-insensitive'):
    Option filter mode.

- optionFilterProp (a value equal to: 'value', 'label'; default 'label'):
    Which prop value of option will be used for filter if filterOption
    is True. If options is set, it should be set to label.

- options (list of dicts; optional):
    Options.

    `options` is a list of dicts with keys:

    - disabled (boolean; optional)

    - label (a list of or a singular dash component, string or number; required)

    - value (string

      Or number; required) | dict with keys:

    - group (string; optional)

    - options (list of dicts; optional)

        `options` is a list of dicts with keys:

        - disabled (boolean; optional)

        - label (a list of or a singular dash component, string or number; required)

        - value (string | number; required)

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- placeholder (string; optional):
    Placeholder text.

- placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; default 'bottomLeft'):
    The position where the selection box pops up.

- popupContainer (a value equal to: 'parent', 'body'; default 'body'):
    Continer of the popup.

- readOnly (boolean; optional):
    Readonly.

- searchValue (string; optional):
    The current input \"search\" text.

- size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
    Sice of the component.

- status (a value equal to: 'error', 'warning'; optional):
    Set validation status.

- style (dict; optional):
    Inline CSS style.

- value (string | number | list of string | numbers; optional):
    Selected value."""
    _children_props = ['options[].label', 'options[].options[].label', 'emptyContent', 'loadingEmptyContent', 'dropdownBefore', 'dropdownAfter']
    _base_nodes = ['emptyContent', 'loadingEmptyContent', 'dropdownBefore', 'dropdownAfter', 'children']
    _namespace = 'anya_dash'
    _type = 'AnyaSelect'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, options=Component.UNDEFINED, listHeight=Component.UNDEFINED, mode=Component.UNDEFINED, disabled=Component.UNDEFINED, size=Component.UNDEFINED, bordered=Component.UNDEFINED, placeholder=Component.UNDEFINED, placement=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, maxTagCount=Component.UNDEFINED, status=Component.UNDEFINED, optionFilterProp=Component.UNDEFINED, searchValue=Component.UNDEFINED, optionFilterMode=Component.UNDEFINED, debounceSearchValue=Component.UNDEFINED, debounceWait=Component.UNDEFINED, autoSpin=Component.UNDEFINED, autoClearSearchValue=Component.UNDEFINED, emptyContent=Component.UNDEFINED, loadingEmptyContent=Component.UNDEFINED, dropdownBefore=Component.UNDEFINED, dropdownAfter=Component.UNDEFINED, allowClear=Component.UNDEFINED, readOnly=Component.UNDEFINED, popupContainer=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allowClear', 'autoClearSearchValue', 'autoSpin', 'bordered', 'className', 'debounceSearchValue', 'debounceWait', 'defaultValue', 'disabled', 'dropdownAfter', 'dropdownBefore', 'emptyContent', 'listHeight', 'loadingEmptyContent', 'maxTagCount', 'mode', 'optionFilterMode', 'optionFilterProp', 'options', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'placement', 'popupContainer', 'readOnly', 'searchValue', 'size', 'status', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowClear', 'autoClearSearchValue', 'autoSpin', 'bordered', 'className', 'debounceSearchValue', 'debounceWait', 'defaultValue', 'disabled', 'dropdownAfter', 'dropdownBefore', 'emptyContent', 'listHeight', 'loadingEmptyContent', 'maxTagCount', 'mode', 'optionFilterMode', 'optionFilterProp', 'options', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'placement', 'popupContainer', 'readOnly', 'searchValue', 'size', 'status', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AnyaSelect, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AnyaTag(Component):
    """An AnyaTag component.
An Ant Design Tag component
See https://ant.design/components/tag

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content to be displayed on the tag.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    CSS classes to be added to the component.

- color (string; optional):
    Color of the tag.

- href (string; optional):
    href if the tag is set to a link.

- style (dict; optional):
    Inline CSS style.

- target (string; default '_blank'):
    target of the link, e.g., \"_blank\"."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'anya_dash'
    _type = 'AnyaTag'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, color=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, href=Component.UNDEFINED, target=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'color', 'href', 'style', 'target']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'color', 'href', 'style', 'target']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AnyaTag, self).__init__(children=children, **args)
